# TwitterFlood

### Kullanım

```bash
cd TwitterFlood
python3 start.py -f <flood> -c <split_count> -ck <consumer_key> -cs <consumer_secret> -a <access_key> -ak <access_secret>

```

### Yapılanlar

* Parametre ile gelen text parametre ile gelen sayı kadar karaktere bölünüp flood halinde atılıyor.
* Class yapısı

### Yapılacaklar

* Tweet resim ile beraber atılması
* base.py içinin clean hale getirilmesi
* consumer key için parametreden çıkartılıp daha efektif kullanılması